@@ -1,18 +1,12 @@
 """Data model for a Z-Wave JS node."""
-from typing import List, Literal, Optional, Union
+from typing import List, Literal, Optional, TypedDict, Union
 
-from ...const import TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED
 from ..device_class import DeviceClassDataType
 from ..device_config import DeviceConfigDataType
 from ..endpoint import EndpointDataType
 from ..value import ValueDataType
 from .statistics import NodeStatisticsDataType
 
-if TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED:
-    from typing_extensions import TypedDict
-else:
-    from typing import TypedDict
-
 
 class FoundNodeDataType(TypedDict, total=False):
     """Represent a found node data dict type."""
