@@ -1,20 +1,10 @@
 """Provide a model for the Z-Wave JS value."""
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, TypedDict, Union
 
-from ..const import (
-    TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED,
-    VALUE_UNKNOWN,
-    CommandClass,
-    ConfigurationValueType,
-)
+from ..const import VALUE_UNKNOWN, CommandClass, ConfigurationValueType
 from ..event import Event
 from ..util.helpers import parse_buffer
 
-if TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED:
-    from typing_extensions import TypedDict
-else:
-    from typing import TypedDict
-
 if TYPE_CHECKING:
     from .node import Node
 
@@ -57,15 +47,15 @@ class ValueDataType(TypedDict, total=False):
 def _init_value(
     node: "Node", val: ValueDataType
 ) -> Union["Value", "ConfigurationValue"]:
-    """Intialize a Value object from ValueDataType."""
+    """Initialize a Value object from ValueDataType."""
     if val["commandClass"] == CommandClass.CONFIGURATION:
         return ConfigurationValue(node, val)
     return Value(node, val)
 
 
-def _get_value_id_from_dict(node: "Node", val: ValueDataType) -> str:
-    """Return ID of value from ValueDataType dict."""
-    return get_value_id(
+def _get_value_id_str_from_dict(node: "Node", val: ValueDataType) -> str:
+    """Return string ID of value from ValueDataType dict."""
+    return get_value_id_str(
         node,
         val["commandClass"],
         val["property"],
@@ -74,14 +64,14 @@ def _get_value_id_from_dict(node: "Node", val: ValueDataType) -> str:
     )
 
 
-def get_value_id(
+def get_value_id_str(
     node: "Node",
     command_class: int,
     property_: Union[str, int],
     endpoint: Optional[int] = None,
     property_key: Optional[Union[str, int]] = None,
 ) -> str:
-    """Return ID of value."""
+    """Return string ID of value."""
     # If endpoint is not provided, assume root endpoint
     endpoint_ = endpoint or 0
     value_id = f"{node.node_id}-{command_class}-{endpoint_}-{property_}"
@@ -196,7 +186,7 @@ class Value:
     @property
     def value_id(self) -> str:
         """Return value ID."""
-        return _get_value_id_from_dict(self.node, self.data)
+        return _get_value_id_str_from_dict(self.node, self.data)
 
     @property
     def metadata(self) -> ValueMetadata:
@@ -265,7 +255,7 @@ class Value:
         self.data.update(data)
         if "newValue" in data:
             self._value = self.data["value"] = data["newValue"]
-        if "value" in data:
+        elif "value" in data:
             self._value = self.data["value"] = data["value"]
         if "metadata" in data:
             self._metadata.update(data["metadata"])
